@@ -1,8 +1,11 @@
 from .profiles import Profiles
+from .manager_accounts import ManagerAccounts
 from .invoices import Invoices
+from .billing import Billing
 from .eligibility import Eligibility
 from .metadata import Metadata
 from .history import History
+from .creative_assets import CreativeAssets
 from .localization import Localization
 from .audiences import Audiences
 from .portfolios import Portfolios
@@ -12,6 +15,8 @@ from . import sb as sponsored_brands
 from . import sd as sponsored_display
 from .attribution import Attribution
 from .brand_metrics import BrandMetrics
+from .advertising_test_account import AdvertisingTestAccount
+from .reports import Reports
 
 __all__ = [
     "sp",
@@ -20,15 +25,20 @@ __all__ = [
     "sponsored_products",
     "sponsored_brands",
     "sponsored_display",
-    "Attribution",
     "Profiles",
+    "ManagerAccounts",
     "Invoices",
+    "Billing",
     "Eligibility",
     "Metadata",
     "History",
+    "CreativeAssets",
     "Localization",
     "Audiences",
     "Portfolios",
     "Insights",
-    "BrandMetrics"
+    "Attribution",
+    "BrandMetrics",
+    "AdvertisingTestAccount",
+    "Reports",
 ]
