@@ -1,10 +1,11 @@
 from .base_client import BaseClient
 from .client import Client
 from .helpers import fill_query_params, sp_endpoint
-from .marketplaces import Marketplaces
+from .marketplaces import Marketplaces, MarketplacesIds, Currencies, CurrencySymbols, Locales
 from .exceptions import AdvertisingApiException
 from .exceptions import AdvertisingApiBadRequestException
 from .exceptions import AdvertisingApiForbiddenException
+from .exceptions import AdvertisingTypeException
 from .credential_provider import CredentialProvider, MissingCredentials
 from .api_response import ApiResponse
 from .utils import Utils
@@ -15,11 +16,16 @@ __all__ = [
     'Client',
     'BaseClient',
     'Marketplaces',
+    'MarketplacesIds',
+    'Currencies',
+    'CurrencySymbols',
+    'Locales',
     'fill_query_params',
     'sp_endpoint',
     'AdvertisingApiException',
     'AdvertisingApiBadRequestException',
     'AdvertisingApiForbiddenException',
+    'AdvertisingTypeException',
     'CredentialProvider',
     'MissingCredentials',
     'Utils'
